cap DLP data at the lengths of chromosomes
Source:R/converting_segments_and_reads.R
cap_dlp_to_chrom_lengths.RdDLP can output bins/segments longer than the actual chromosomes as it chops
to 500kb bins. This function sets the end column to be no longer than
the chromosome it occurs on.
Usage
cap_dlp_to_chrom_lengths(
rs_df,
chrom_col = "chr",
genome_version = c("hg19", "hg38")
)